### INTRODUCTION
"pymeli.為美麗而生" pymeili is a module to beautify your python plot or terminal text with more simple way. the design idea is from Navigraph aeronautical chart.

### IMPORTANT
Before using this module, you need to install font-packages: https://dwl.freefontsfamily.com/download/futura/; 
moving the font file to installed module folder(e.g. C:\Users\Username\AppData\Local\Programs\Python\Python311\Lib\site-packages\pymeili).
For more information and instruction, please go to: https://github.com/VVVICTORZHOU/resources.git or you can just download the font file from the link above.

### INSTALLATION
- Install guide: (run on your powershell or cmd)

    `pip install pymeili`

- Update guide: (run on your powershell or cmd)

    `pip install --upgrade pymeili`

